==> jc-1.4.0.tar.gz: java/util/WeakHashMap__24WeakBucket.h <==
// class java.util.WeakHashMap$WeakBucket

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 77273604094666c7 java_lang_ref_Reference
// @dep_class 14fe490ec89fb98 java_lang_ref_WeakReference
// @dep_class 6c46fd701228aaab java_util_WeakHashMap__24WeakBucket

// header file dependencies
// @dep_header java_lang_ref_WeakReference

#include "java/lang/ref/WeakReference.h"

#ifndef _JC_java_util_WeakHashMap__24WeakBucket_H_
#define _JC_java_util_WeakHashMap__24WeakBucket_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_ref_ReferenceQueue$object;
struct _jc_java_util_WeakHashMap__24WeakBucket$object;
struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object;

// Typedefs
typedef struct _jc_java_util_WeakHashMap__24WeakBucket$sub_refs	_jc_java_util_WeakHashMap__24WeakBucket$sub_refs;
typedef struct _jc_java_util_WeakHashMap__24WeakBucket$sub_nonrefs	_jc_java_util_WeakHashMap__24WeakBucket$sub_nonrefs;
typedef struct _jc_java_util_WeakHashMap__24WeakBucket$refs	_jc_java_util_WeakHashMap__24WeakBucket$refs;
typedef struct _jc_java_util_WeakHashMap__24WeakBucket$nonrefs	_jc_java_util_WeakHashMap__24WeakBucket$nonrefs;
typedef struct _jc_java_util_WeakHashMap__24WeakBucket$object	_jc_java_util_WeakHashMap__24WeakBucket$object;

typedef const struct _jc_java_util_WeakHashMap__24WeakBucket$vmethods	_jc_java_util_WeakHashMap__24WeakBucket$vmethods;
typedef const struct _jc_java_util_WeakHashMap__24WeakBucket$vtable	_jc_java_util_WeakHashMap__24WeakBucket$vtable;
typedef const struct _jc_java_util_WeakHashMap__24WeakBucket$vtype	_jc_java_util_WeakHashMap__24WeakBucket$vtype;

// Constructors
extern void _jc_java_util_WeakHashMap__24WeakBucket$method$_init$ff320a02b5e07d13(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_ref_ReferenceQueue$object *, struct _jc_java_lang_Object$object *, jint);

// Virtual methods
extern struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *_jc_java_util_WeakHashMap__24WeakBucket$method$getEntry$de871fde5415e290(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_WeakHashMap__24WeakBucket$method_info$getEntry$de871fde5415e290;

// Virtual methods structure
struct _jc_java_util_WeakHashMap__24WeakBucket$vmethods {
	struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object	*(*getEntry$de871fde5415e290)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket$object *);
};

// Vtable
struct _jc_java_util_WeakHashMap__24WeakBucket$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_ref_Reference$vmethods	java_lang_ref_Reference;
	_jc_java_lang_ref_WeakReference$vmethods	java_lang_ref_WeakReference;
	_jc_java_util_WeakHashMap__24WeakBucket$vmethods	java_util_WeakHashMap__24WeakBucket;
};

// Vtype
struct _jc_java_util_WeakHashMap__24WeakBucket$vtype {
	_jc_type			type;
	_jc_java_util_WeakHashMap__24WeakBucket$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_WeakHashMap__24WeakBucket$sub_refs {
	struct _jc_java_lang_Object$object	*value;
	struct _jc_java_util_WeakHashMap__24WeakBucket$object	*next;
};

// Reference instance fields (object)
struct _jc_java_util_WeakHashMap__24WeakBucket$refs {
    _jc_java_util_WeakHashMap__24WeakBucket$sub_refs	java_util_WeakHashMap__24WeakBucket;
    _jc_java_lang_ref_WeakReference$sub_refs	java_lang_ref_WeakReference;
    _jc_java_lang_ref_Reference$sub_refs	java_lang_ref_Reference;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_WeakHashMap__24WeakBucket$sub_nonrefs {
	jint	slot;
};

// Non-reference instance fields (object)
struct _jc_java_util_WeakHashMap__24WeakBucket$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_ref_Reference$sub_nonrefs	java_lang_ref_Reference;
    _jc_java_lang_ref_WeakReference$sub_nonrefs	java_lang_ref_WeakReference;
    _jc_java_util_WeakHashMap__24WeakBucket$sub_nonrefs	java_util_WeakHashMap__24WeakBucket;
};

// Object instance structure
struct _jc_java_util_WeakHashMap__24WeakBucket$object {
	_jc_java_util_WeakHashMap__24WeakBucket$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_WeakHashMap__24WeakBucket$vtype	*vtype;
	_jc_java_util_WeakHashMap__24WeakBucket$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_WeakHashMap__24WeakBucket$vtype _jc_java_util_WeakHashMap__24WeakBucket$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_WeakHashMap__24WeakBucket, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_WeakHashMap__24WeakBucket$class_object;

#endif	/* _JC_java_util_WeakHashMap__24WeakBucket_H_ */

==> jc-1.4.6.tar.gz: java/util/WeakHashMap__24WeakBucket.h <==
// class java.util.WeakHashMap$WeakBucket

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 77273604094666c7 java_lang_ref_Reference
// @dep_class 14fe490ec89fb98 java_lang_ref_WeakReference
// @dep_class 6c46fd701228aaab java_util_WeakHashMap__24WeakBucket

// header file dependencies
// @dep_header java_lang_ref_WeakReference

#include "java/lang/ref/WeakReference.h"

#ifndef _JC_java_util_WeakHashMap__24WeakBucket_H_
#define _JC_java_util_WeakHashMap__24WeakBucket_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_ref_ReferenceQueue$object;
struct _jc_java_util_WeakHashMap__24WeakBucket$object;
struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object;

// Typedefs
typedef struct _jc_java_util_WeakHashMap__24WeakBucket$sub_refs	_jc_java_util_WeakHashMap__24WeakBucket$sub_refs;
typedef struct _jc_java_util_WeakHashMap__24WeakBucket$sub_nonrefs	_jc_java_util_WeakHashMap__24WeakBucket$sub_nonrefs;
typedef struct _jc_java_util_WeakHashMap__24WeakBucket$refs	_jc_java_util_WeakHashMap__24WeakBucket$refs;
typedef struct _jc_java_util_WeakHashMap__24WeakBucket$nonrefs	_jc_java_util_WeakHashMap__24WeakBucket$nonrefs;
typedef struct _jc_java_util_WeakHashMap__24WeakBucket$object	_jc_java_util_WeakHashMap__24WeakBucket$object;

typedef const struct _jc_java_util_WeakHashMap__24WeakBucket$vmethods	_jc_java_util_WeakHashMap__24WeakBucket$vmethods;
typedef const struct _jc_java_util_WeakHashMap__24WeakBucket$vtable	_jc_java_util_WeakHashMap__24WeakBucket$vtable;
typedef const struct _jc_java_util_WeakHashMap__24WeakBucket$vtype	_jc_java_util_WeakHashMap__24WeakBucket$vtype;

// Constructors
extern void _jc_java_util_WeakHashMap__24WeakBucket$method$_init$ff320a02b5e07d13(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_ref_ReferenceQueue$object *, struct _jc_java_lang_Object$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object *_jc_java_util_WeakHashMap__24WeakBucket$method$getEntry$de871fde5415e290(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_WeakHashMap__24WeakBucket$method_info$getEntry$de871fde5415e290;

// Virtual methods structure
struct _jc_java_util_WeakHashMap__24WeakBucket$vmethods {
	struct _jc_java_util_WeakHashMap__24WeakBucket__24WeakEntry$object	*(*getEntry$de871fde5415e290)(_jc_env *, struct _jc_java_util_WeakHashMap__24WeakBucket$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_WeakHashMap__24WeakBucket$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_ref_Reference$vmethods	java_lang_ref_Reference;
	_jc_java_lang_ref_WeakReference$vmethods	java_lang_ref_WeakReference;
	_jc_java_util_WeakHashMap__24WeakBucket$vmethods	java_util_WeakHashMap__24WeakBucket;
};

// Vtype
struct _jc_java_util_WeakHashMap__24WeakBucket$vtype {
	_jc_type			type;
	_jc_java_util_WeakHashMap__24WeakBucket$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_WeakHashMap__24WeakBucket$sub_refs {
	struct _jc_java_lang_Object$object	*value;
	struct _jc_java_util_WeakHashMap__24WeakBucket$object	*next;
};

// Reference instance fields (object)
struct _jc_java_util_WeakHashMap__24WeakBucket$refs {
    _jc_java_util_WeakHashMap__24WeakBucket$sub_refs	java_util_WeakHashMap__24WeakBucket;
    _jc_java_lang_ref_WeakReference$sub_refs	java_lang_ref_WeakReference;
    _jc_java_lang_ref_Reference$sub_refs	java_lang_ref_Reference;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_WeakHashMap__24WeakBucket$sub_nonrefs {
	jint	slot;
};

// Non-reference instance fields (object)
struct _jc_java_util_WeakHashMap__24WeakBucket$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_ref_Reference$sub_nonrefs	java_lang_ref_Reference;
    _jc_java_lang_ref_WeakReference$sub_nonrefs	java_lang_ref_WeakReference;
    _jc_java_util_WeakHashMap__24WeakBucket$sub_nonrefs	java_util_WeakHashMap__24WeakBucket;
};

// Object instance structure
struct _jc_java_util_WeakHashMap__24WeakBucket$object {
	_jc_java_util_WeakHashMap__24WeakBucket$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_WeakHashMap__24WeakBucket$vtype	*vtype;
	_jc_java_util_WeakHashMap__24WeakBucket$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_WeakHashMap__24WeakBucket$vtype _jc_java_util_WeakHashMap__24WeakBucket$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_WeakHashMap__24WeakBucket, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_WeakHashMap__24WeakBucket$class_object;

#endif	/* _JC_java_util_WeakHashMap__24WeakBucket_H_ */
